@@ -9,10 +9,11 @@ from PyQt4.QtCore import Qt
 from PyQt4 import QtCore, QtGui
 
 class Server(QtCore.QObject):
-	def __init__(self, namei,  serverI,  log,  pwd, parent=None):
+	def __init__(self, namei,  serverI,  log,  pwd, portc,  parent=None):
 		QObject.__init__(self, parent)
 		
 		self.name = namei
 		self.server = serverI
 		self.login = log
 		self.password = pwd
+		self.port = portc
