@@ -112,6 +112,7 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 		self.server =""
 		self.user =""
 		self.pwd =""
+		self.port =21
 		
     def switchLocalDir(self):
 		self.backupLocalDir = self.localdir
@@ -167,7 +168,8 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 				#We need to create the dir where the user clicked on
 				#fh =ftpFileHelper(self.server, self.user, self.pwd,  self)
 				#fh.makeDirectoryOnServer(self.currentRemotePath+"/",  file)
-				ftplib_i = FTP(str(self.server))
+				ftplib_i = FTP()
+				ftplib_i.connect(str(self.server),  str(self.port))
 				ftplib_i.login(str(self.user),  str(self.pwd))
 				ftplib_i.cwd(str(self.currentRemotePath))
 				try :
@@ -337,7 +339,7 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 		for i in dirlist:
 			if i !="." and i!="..":
 				print baseremotePath + " File ="+i
-				fh =ftpFileHelper(self.server, self.user, self.pwd,  self)
+				fh =ftpFileHelper(self.server, self.user, self.pwd, self.port, self)
 				fh.uploadFile(dir.path()+"/"+i, baseremotePath+"/"+i)
 		
 			
@@ -356,7 +358,7 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 		self.openLocation.show()
 
 	#Connect to Host with the login information
-    def connectToServer(self, serverc,  userc,  pwdc):
+    def connectToServer(self, serverc,  userc,  pwdc,  portc=21):
         if self.ftp:
 			self.ftp.abort()
 			self.ftp.deleteLater()
@@ -368,9 +370,13 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
         self.server = serverc
         self.user = userc
         self.pwd = pwdc
+        self.port= portc
 		
         self.ftp = QFtp(self)
-        self.ftp.connectToHost(self.server)
+        (portInt,  ok)=self.port.toInt()
+        if not ok:
+			portInt = 21
+        self.ftp.connectToHost(self.server,  portInt)
         self.ftp.login(self.user, self.pwd)
 		
         self.ftp.commandFinished.connect(self.ftpCommandFinished)
@@ -543,7 +549,7 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 			substring = QString(self.actionRemotePath.mid(QString(self.startRemotePath).size(), self.actionRemotePath.size()))
 			#print "process: Substring = "+substring
 			
-			ft = ftpFileHelper(self.server,  self.user, self.pwd,  self)
+			ft = ftpFileHelper(self.server,  self.user, self.pwd,  self.port,  self)
 			ft.downloadFilesFromDirectory(self.startLocalPath+"/"+substring,  self.actionRemotePath)
 			
 			
