@@ -39,6 +39,7 @@ class OpenServer(QMainWindow, Ui_MainWindow):
 		self.m_le_password.setText(server.password)
 		self.m_le_server.setText(server.server)
 		self.m_le_user.setText(server.login)
+		self.m_le_port.setText(server.port)
     
     @pyqtSignature("")
     def on_m_bu_open_bookmarks_clicked(self):
@@ -50,7 +51,7 @@ class OpenServer(QMainWindow, Ui_MainWindow):
     
     @pyqtSignature("")
     def on_m_bu_connect_clicked(self):
-        self.parentWindow.connectToServer(self.m_le_server.text(), self.m_le_user.text(),  self.m_le_password.text())
+        self.parentWindow.connectToServer(self.m_le_server.text(), self.m_le_user.text(),  self.m_le_password.text(),  self.m_le_port.text())
         self.hide()
 		
 
